@@ -12,9 +12,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General
- * Public License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Public License along with this library. If not, see <https://www.gnu.org/licenses/>.
  */
 
 #pragma once
@@ -132,4 +130,16 @@ char **ostree_kernel_args_to_strv (OstreeKernelArgs *kargs);
 _OSTREE_PUBLIC
 char *ostree_kernel_args_to_string (OstreeKernelArgs *kargs);
 
+_OSTREE_PUBLIC
+void ostree_kernel_args_append_if_missing (OstreeKernelArgs *kargs, 
+                                           const char *arg);
+
+_OSTREE_PUBLIC
+gboolean ostree_kernel_args_contains (OstreeKernelArgs *kargs,
+                                      const char *arg);
+
+_OSTREE_PUBLIC
+gboolean ostree_kernel_args_delete_if_present (OstreeKernelArgs *kargs,
+                                               const char       *arg,
+                                               GError          **error);
 G_END_DECLS
