@@ -1334,9 +1334,9 @@ get_fallback_headers (OstreeRepo               *self,
  *   - inline-parts: b: Put part data in header, to get a single file delta.  Default FALSE.
  *   - verbose: b: Print diagnostic messages.  Default FALSE.
  *   - endianness: b: Deltas use host byte order by default; this option allows choosing (G_BIG_ENDIAN or G_LITTLE_ENDIAN)
- *   - filename: ay: Save delta superblock to this filename, and parts in the same directory.  Default saves to repository.
- *   - sign-name: ay: Signature type to use.
- *   - sign-key-ids: as: Array of keys used to sign delta superblock.
+ *   - filename: ^ay: Save delta superblock to this filename (bytestring), and parts in the same directory.  Default saves to repository.
+ *   - sign-name: ^ay: Signature type to use (bytestring).
+ *   - sign-key-ids: ^as: NULL-terminated array of keys used to sign delta superblock.
  */
 gboolean
 ostree_repo_static_delta_generate (OstreeRepo                   *self,
@@ -1369,7 +1369,6 @@ ostree_repo_static_delta_generate (OstreeRepo                   *self,
   g_autoptr(GPtrArray) builder_parts = g_ptr_array_new_with_free_func ((GDestroyNotify)ostree_static_delta_part_builder_unref);
   g_autoptr(GPtrArray) builder_fallback_objects = g_ptr_array_new_with_free_func ((GDestroyNotify)g_variant_unref);
   g_auto(GLnxTmpfile) descriptor_tmpf = { 0, };
-  g_autoptr(OtVariantBuilder) descriptor_builder = NULL;
   const char *opt_sign_name;
   const char **opt_key_ids;
 
@@ -1410,9 +1409,13 @@ ostree_repo_static_delta_generate (OstreeRepo                   *self,
 
   if (!g_variant_lookup (params, "filename", "^&ay", &opt_filename))
     opt_filename = NULL;
+  else if (opt_filename[0] == '\0')
+    return glnx_throw (error, "Invalid 'filename' parameter");
 
   if (!g_variant_lookup (params, "sign-name", "^&ay", &opt_sign_name))
     opt_sign_name = NULL;
+  else if (opt_sign_name[0] == '\0')
+    return glnx_throw (error, "Invalid 'sign-name' parameter");
 
   if (!g_variant_lookup (params, "sign-key-ids", "^a&s", &opt_key_ids))
     opt_key_ids = NULL;
@@ -1456,7 +1459,10 @@ ostree_repo_static_delta_generate (OstreeRepo                   *self,
                                       &descriptor_tmpf, error))
     return FALSE;
 
-  descriptor_builder = ot_variant_builder_new (G_VARIANT_TYPE (OSTREE_STATIC_DELTA_SUPERBLOCK_FORMAT), descriptor_tmpf.fd);
+  g_autoptr(OtVariantBuilder) descriptor_builder =
+    ot_variant_builder_new (G_VARIANT_TYPE (OSTREE_STATIC_DELTA_SUPERBLOCK_FORMAT),
+                            descriptor_tmpf.fd);
+  g_assert (descriptor_builder != NULL);
 
   /* Open the metadata dict */
   if (!ot_variant_builder_open (descriptor_builder, G_VARIANT_TYPE ("a{sv}"), error))
@@ -1603,7 +1609,6 @@ ostree_repo_static_delta_generate (OstreeRepo                   *self,
       const gchar *signature_key = NULL;
       g_autoptr(GVariantBuilder) signature_builder = NULL;
       g_auto(GLnxTmpfile) descriptor_sign_tmpf = { 0, };
-      g_autoptr(OtVariantBuilder) descriptor_sign_builder = NULL;
 
       lseek (descriptor_tmpf.fd, 0, SEEK_SET);
       tmpdata = glnx_fd_readall_bytes (descriptor_tmpf.fd, cancellable, error);
@@ -1640,8 +1645,10 @@ ostree_repo_static_delta_generate (OstreeRepo                   *self,
                                           &descriptor_sign_tmpf, error))
         return FALSE;
 
-      descriptor_sign_builder = ot_variant_builder_new (G_VARIANT_TYPE (OSTREE_STATIC_DELTA_SIGNED_FORMAT),
-                                                        descriptor_sign_tmpf.fd);
+      g_autoptr(OtVariantBuilder) descriptor_sign_builder =
+        ot_variant_builder_new (G_VARIANT_TYPE (OSTREE_STATIC_DELTA_SIGNED_FORMAT),
+                                descriptor_sign_tmpf.fd);
+      g_assert (descriptor_sign_builder != NULL);
 
       if (!ot_variant_builder_add (descriptor_sign_builder, error, "t",
                                    GUINT64_TO_BE (OSTREE_STATIC_DELTA_SIGNED_MAGIC)))
