@@ -1,5 +1,6 @@
 /*
  * Copyright (C) 2013 Colin Walters <walters@verbum.org>
+ * Copyright (C) 2022 Igalia S.L.
  *
  * SPDX-License-Identifier: LGPL-2.0+
  *
@@ -82,7 +83,7 @@ ostree_sysroot_finalize (GObject *object)
   g_clear_pointer (&self->deployments, g_ptr_array_unref);
   g_clear_object (&self->booted_deployment);
   g_clear_object (&self->staged_deployment);
-  g_clear_pointer (&self->staged_deployment_data, (GDestroyNotify)g_variant_unref);
+  g_clear_pointer (&self->staged_deployment_data, g_variant_unref);
 
   glnx_release_lock_file (&self->lock);
 
@@ -258,6 +259,63 @@ ostree_sysroot_set_mount_namespace_in_use (OstreeSysroot  *self)
   self->mount_namespace_in_use = TRUE;
 }
 
+/**
+ * ostree_sysroot_initialize_with_mount_namespace:
+ *
+ * Prepare the current process for modifying a booted sysroot, if applicable.
+ * This function subsumes the functionality of `ostree_sysroot_initialize`
+ * and may be invoked wherever that function is.
+ *
+ * If the sysroot does not appear to be booted, or where the current process is not uid 0,
+ * this function returns successfully.
+ *
+ * Otherwise, if the process is in the same mount namespace as pid 1, create
+ * a new namespace.
+ *
+ * If you invoke this function, it must be before ostree_sysroot_load(); it may
+ * be invoked before or after ostree_sysroot_initialize().
+ *
+ * Since: 2022.7
+ */
+gboolean
+ostree_sysroot_initialize_with_mount_namespace (OstreeSysroot *self, GCancellable *cancellable, GError **error)
+{
+  GLNX_AUTO_PREFIX_ERROR ("Initializing with mountns", error);
+  /* Must be before we're loaded, as otherwise we'd have to close/reopen all our
+     fds, e.g. the repo */
+  g_assert (self->loadstate < OSTREE_SYSROOT_LOAD_STATE_LOADED);
+
+  if (!ostree_sysroot_initialize (self, error))
+    return FALSE;
+
+  /* Do nothing if we're not privileged */
+  if (getuid () != 0)
+    return TRUE;
+
+  /* We also assume operating on non-booted roots won't have a readonly sysroot */
+  if (!self->root_is_ostree_booted)
+    return TRUE;
+
+  g_autofree char *mntns_pid1 =
+    glnx_readlinkat_malloc (AT_FDCWD, "/proc/1/ns/mnt", cancellable, error);
+  if (!mntns_pid1)
+    return glnx_prefix_error (error, "Reading /proc/1/ns/mnt");
+  g_autofree char *mntns_self =
+    glnx_readlinkat_malloc (AT_FDCWD, "/proc/self/ns/mnt", cancellable, error);
+  if (!mntns_self)
+    return glnx_prefix_error (error, "Reading /proc/self/ns/mnt");
+
+  // If the mount namespaces are the same, we need to unshare().
+  if (strcmp (mntns_pid1, mntns_self) == 0)
+    { 
+      if (unshare (CLONE_NEWNS) < 0)
+        return glnx_throw_errno_prefix (error, "Failed to invoke unshare(CLONE_NEWNS)");
+    }
+
+  ostree_sysroot_set_mount_namespace_in_use (self);
+  return TRUE;
+}
+
 /**
  * ostree_sysroot_get_path:
  * @self: Sysroot
@@ -327,14 +385,13 @@ gboolean
 _ostree_sysroot_ensure_writable (OstreeSysroot      *self,
                                  GError            **error)
 {
+  if (!ostree_sysroot_initialize (self, error))
+    return FALSE;
+
   /* Do nothing if no mount namespace is in use */
   if (!self->mount_namespace_in_use)
     return TRUE;
 
-  /* If a mount namespace is in use, ensure we're initialized */
-  if (!ostree_sysroot_initialize (self, error))
-    return FALSE;
-
   /* If we aren't operating on a booted system, then we don't
    * do anything with mounts.
    */
@@ -356,6 +413,8 @@ _ostree_sysroot_ensure_writable (OstreeSysroot      *self,
   ostree_sysroot_unload (self);
   if (!ensure_sysroot_fd (self, error))
     return FALSE;
+  if (!_ostree_sysroot_ensure_boot_fd (self, error))
+    return FALSE;
 
   return TRUE;
 }
@@ -1016,7 +1075,7 @@ _ostree_sysroot_reload_staged (OstreeSysroot *self,
   g_assert (self->booted_deployment);
 
   g_clear_object (&self->staged_deployment);
-  g_clear_pointer (&self->staged_deployment_data, (GDestroyNotify)g_variant_unref);
+  g_clear_pointer (&self->staged_deployment_data, g_variant_unref);
 
   /* Read the staged state from disk */
   glnx_autofd int fd = -1;
@@ -1264,7 +1323,7 @@ ostree_sysroot_get_booted_deployment (OstreeSysroot       *self)
 OstreeDeployment *
 ostree_sysroot_require_booted_deployment (OstreeSysroot *self, GError **error)
 {
-  g_return_val_if_fail (self->loadstate == OSTREE_SYSROOT_LOAD_STATE_LOADED, NULL);
+  g_assert (self->loadstate == OSTREE_SYSROOT_LOAD_STATE_LOADED);
 
   if (!self->booted_deployment)
     return glnx_null_throw (error, "Not currently booted into an OSTree system");
@@ -1283,7 +1342,7 @@ ostree_sysroot_require_booted_deployment (OstreeSysroot *self, GError **error)
 OstreeDeployment *
 ostree_sysroot_get_staged_deployment (OstreeSysroot       *self)
 {
-  g_return_val_if_fail (self->loadstate == OSTREE_SYSROOT_LOAD_STATE_LOADED, NULL);
+  g_assert (self->loadstate == OSTREE_SYSROOT_LOAD_STATE_LOADED);
 
   return self->staged_deployment;
 }
@@ -1297,7 +1356,7 @@ ostree_sysroot_get_staged_deployment (OstreeSysroot       *self)
 GPtrArray *
 ostree_sysroot_get_deployments (OstreeSysroot  *self)
 {
-  g_return_val_if_fail (self->loadstate == OSTREE_SYSROOT_LOAD_STATE_LOADED, NULL);
+  g_assert (self->loadstate == OSTREE_SYSROOT_LOAD_STATE_LOADED);
 
   GPtrArray *copy = g_ptr_array_new_with_free_func ((GDestroyNotify)g_object_unref);
   for (guint i = 0; i < self->deployments->len; i++)
@@ -1522,7 +1581,7 @@ ostree_sysroot_query_deployments_for (OstreeSysroot     *self,
                                       OstreeDeployment  **out_pending,
                                       OstreeDeployment  **out_rollback)
 {
-  g_return_if_fail (osname != NULL || self->booted_deployment != NULL);
+  g_assert (osname != NULL || self->booted_deployment != NULL);
   g_autoptr(OstreeDeployment) ret_pending = NULL;
   g_autoptr(OstreeDeployment) ret_rollback = NULL;
 
@@ -1893,6 +1952,7 @@ ostree_sysroot_simple_write_deployment (OstreeSysroot      *sysroot,
   /* tracks when we come across the booted deployment */
   gboolean before_booted = TRUE;
   gboolean before_merge = TRUE;
+  g_assert (deployments);
   for (guint i = 0; i < deployments->len; i++)
     {
       OstreeDeployment *deployment = deployments->pdata[i];
