@@ -14,9 +14,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this library. If not, see <https://www.gnu.org/licenses/>.
  *
  * Author: Colin Walters <walters@verbum.org>
  */
@@ -82,10 +80,13 @@ ot_gfile_ensure_unlinked (GFile         *path,
                           GCancellable  *cancellable,
                           GError       **error)
 {
-  if (unlink (gs_file_get_path_cached (path)) != 0)
+  g_assert (path);
+  const char *pathc = gs_file_get_path_cached (path);
+  g_assert (pathc);
+  if (unlink (pathc) != 0)
     {
       if (errno != ENOENT)
-        return glnx_throw_errno_prefix (error, "unlink(%s)", gs_file_get_path_cached (path));
+        return glnx_throw_errno_prefix (error, "unlink(%s)", pathc);
     }
   return TRUE;
 }
