@@ -1,6 +1,8 @@
 /*
  * Copyright (C) 2015 Colin Walters <walters@verbum.org>
  *
+ * SPDX-License-Identifier: LGPL-2.0+
+ *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
@@ -12,9 +14,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this library. If not, see <https://www.gnu.org/licenses/>.
  */
 
 #pragma once
@@ -32,5 +32,10 @@ ot_parse_keyvalue (const char  *keyvalue,
                    char       **out_key,
                    char       **out_value,
                    GError     **error);
+gboolean
+ot_ptr_array_find_with_equal_func (GPtrArray     *haystack,
+                                   gconstpointer  needle,
+                                   GEqualFunc     equal_func,
+                                   guint         *index_);
 
 G_END_DECLS
