@@ -14,9 +14,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this library. If not, see <https://www.gnu.org/licenses/>.
  *
  * Author: Alexander Larsson <alexl@redhat.com>.
  */
@@ -760,11 +758,9 @@ struct _OtVariantBuilder {
 static OtVariantBuilderInfo *
 ot_variant_builder_info_new (OtVariantBuilder *builder, const GVariantType *type)
 {
-  OtVariantBuilderInfo *info;
+  g_assert (g_variant_type_is_container (type));
 
-  info = (OtVariantBuilderInfo *) g_slice_new0 (OtVariantBuilderInfo);
-
-  g_return_val_if_fail (g_variant_type_is_container (type), NULL);
+  OtVariantBuilderInfo *info = (OtVariantBuilderInfo *) g_slice_new0 (OtVariantBuilderInfo);
 
   info->builder = builder;
   info->type = g_variant_type_copy (type);
@@ -832,7 +828,7 @@ static void
 ot_variant_builder_info_free (OtVariantBuilderInfo *info)
 {
   if (info->parent)
-    ot_variant_builder_info_free (info);
+    ot_variant_builder_info_free (info->parent);
 
   g_variant_type_free (info->type);
   g_array_unref (info->child_ends);
@@ -845,11 +841,9 @@ OtVariantBuilder *
 ot_variant_builder_new (const GVariantType *type,
                         int fd)
 {
-  OtVariantBuilder *builder;
+  g_assert (g_variant_type_is_container (type));
 
-  builder = (OtVariantBuilder *) g_slice_new0 (OtVariantBuilder);
-
-  g_return_val_if_fail (g_variant_type_is_container (type), NULL);
+  OtVariantBuilder *builder = (OtVariantBuilder *) g_slice_new0 (OtVariantBuilder);
 
   builder->head = ot_variant_builder_info_new (builder, type);
   builder->ref_count = 1;
@@ -909,6 +903,7 @@ ot_variant_builder_pre_add (OtVariantBuilderInfo *info,
       const GVariantMemberInfo *member_info;
 
       member_info = g_variant_type_info_member_info (info->type_info, info->n_children);
+      g_assert (member_info);
       alignment = member_info->type_info->alignment;
     }
   else if (g_variant_type_is_array (info->type))
@@ -959,6 +954,7 @@ ot_variant_builder_post_add (OtVariantBuilderInfo *info,
       const GVariantMemberInfo *member_info;
 
       member_info = g_variant_type_info_member_info (info->type_info, info->n_children);
+      g_assert (member_info);
       if (member_info->ending_type == G_VARIANT_MEMBER_ENDING_OFFSET)
         ot_variant_builder_add_child_end (info);
     }
@@ -1083,23 +1079,21 @@ ot_variant_builder_open (OtVariantBuilder *builder,
                          GError **error)
 {
   OtVariantBuilderInfo *info = builder->head;
-  OtVariantBuilderInfo *new_info;
 
-  g_return_val_if_fail (info->n_children < info->max_items,
-                        FALSE);
-  g_return_val_if_fail (!info->expected_type ||
+  g_assert (info->n_children < info->max_items);
+  g_assert (!info->expected_type ||
                         g_variant_type_is_subtype_of (type,
-                                                      info->expected_type),
-                        FALSE);
-  g_return_val_if_fail (!info->prev_item_type ||
+                                                      info->expected_type));
+  g_assert (!info->prev_item_type ||
                         g_variant_type_is_subtype_of (info->prev_item_type,
-                                                      type),
-                        FALSE);
+                                                      type));
 
   if (!ot_variant_builder_pre_add (info, type, error))
     return FALSE;
 
-  new_info = ot_variant_builder_info_new (builder, type);
+  OtVariantBuilderInfo *new_info = ot_variant_builder_info_new (builder, type);
+  g_assert (new_info != NULL);
+
   new_info->parent = info;
 
   /* push the prev_item_type down into the subcontainer */
