@@ -389,7 +389,7 @@ ostree_builtin_pull (int argc, char **argv, OstreeCommandInvocation *invocation,
     if (!console.is_tty && !opt_dry_run)
       {
         g_assert (progress);
-        const char *status = ostree_async_progress_get_status (progress);
+        g_autofree char *status = ostree_async_progress_get_status (progress);
         if (status)
           g_print ("%s\n", status);
       }
