@@ -28,7 +28,6 @@
 #include <string.h>
 #include <sys/statvfs.h>
 #include <sys/mount.h>
-#include <linux/fs.h>
 
 #include "ot-main.h"
 #include "ostree.h"
@@ -579,6 +578,44 @@ on_sysroot_journal_msg (OstreeSysroot *sysroot,
   g_print ("%s\n", msg);
 }
 
+gboolean
+ostree_admin_sysroot_load (OstreeSysroot            *sysroot,
+                           OstreeAdminBuiltinFlags   flags,
+                           GCancellable             *cancellable,
+                           GError                  **error)
+{
+  if ((flags & OSTREE_ADMIN_BUILTIN_FLAG_UNLOCKED) == 0)
+    {
+      /* Set up the mount namespace, if applicable */
+      if (!ostree_sysroot_initialize_with_mount_namespace (sysroot, cancellable, error))
+        return FALSE;
+
+      /* Released when sysroot is finalized, or on process exit */
+      if (!ot_admin_sysroot_lock (sysroot, error))
+        return FALSE;
+    }
+
+  if (!ostree_sysroot_load (sysroot, cancellable, error))
+    return FALSE;
+
+  if (flags & OSTREE_ADMIN_BUILTIN_FLAG_SUPERUSER)
+    {
+      OstreeDeployment *booted = ostree_sysroot_get_booted_deployment (sysroot);
+
+      /* Only require root if we're manipulating a booted sysroot. (Mostly
+       * useful for the test suite)
+       */
+      if (booted && getuid () != 0)
+        {
+          g_set_error (error, G_IO_ERROR, G_IO_ERROR_PERMISSION_DENIED,
+                       "You must be root to perform this command");
+          return FALSE;
+        }
+    }
+
+  return TRUE;
+}
+
 gboolean
 ostree_admin_option_context_parse (GOptionContext *context,
                                    const GOptionEntry *main_entries,
@@ -615,49 +652,12 @@ ostree_admin_option_context_parse (GOptionContext *context,
     return FALSE;
   g_signal_connect (sysroot, "journal-msg", G_CALLBACK (on_sysroot_journal_msg), NULL);
 
-  if ((flags & OSTREE_ADMIN_BUILTIN_FLAG_UNLOCKED) == 0)
+  if (opt_print_current_dir || (flags & OSTREE_ADMIN_BUILTIN_FLAG_NO_LOAD) == 0)
     {
-      /* If we're requested to lock the sysroot, first check if we're operating
-       * on a booted (not physical) sysroot.  Then find out if the /sysroot
-       * subdir is a read-only mount point, and if so, create a new mount
-       * namespace and tell the sysroot that we've done so. See the docs for
-       * ostree_sysroot_set_mount_namespace_in_use().
-       *
-       * This is a conservative approach; we could just always
-       * unshare() too.
-       */
-      if (ostree_sysroot_is_booted (sysroot))
-        {
-          gboolean setup_ns = FALSE;
-          if (!maybe_setup_mount_namespace (&setup_ns, error))
-            return FALSE;
-          if (setup_ns)
-            ostree_sysroot_set_mount_namespace_in_use (sysroot);
-        }
-
-      /* Released when sysroot is finalized, or on process exit */
-      if (!ot_admin_sysroot_lock (sysroot, error))
+      if (!ostree_admin_sysroot_load (sysroot, flags, cancellable, error))
         return FALSE;
     }
 
-  if (!ostree_sysroot_load (sysroot, cancellable, error))
-    return FALSE;
-
-  if (flags & OSTREE_ADMIN_BUILTIN_FLAG_SUPERUSER)
-    {
-      OstreeDeployment *booted = ostree_sysroot_get_booted_deployment (sysroot);
-
-      /* Only require root if we're manipulating a booted sysroot. (Mostly
-       * useful for the test suite)
-       */
-      if (booted && getuid () != 0)
-        {
-          g_set_error (error, G_IO_ERROR, G_IO_ERROR_PERMISSION_DENIED,
-                       "You must be root to perform this command");
-          return FALSE;
-        }
-    }
-
   if (opt_print_current_dir)
     {
       g_autoptr(GPtrArray) deployments = NULL;
