@@ -14,9 +14,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this library. If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
@@ -33,12 +31,14 @@ gboolean
 ot_test_run_libtest (const char *cmd, GError **error)
 {
   const char *srcdir = g_getenv ("G_TEST_SRCDIR");
-  g_autoptr(GPtrArray) argv = g_ptr_array_new ();
-  g_autoptr(GString) cmdstr = g_string_new ("");
+  g_assert (srcdir != NULL);
+  g_assert (cmd != NULL);
 
+  g_autoptr(GPtrArray) argv = g_ptr_array_new ();
   g_ptr_array_add (argv, "bash");
   g_ptr_array_add (argv, "-c");
 
+  g_autoptr(GString) cmdstr = g_string_new ("");
   g_string_append (cmdstr, "set -xeuo pipefail; . ");
   g_string_append (cmdstr, srcdir);
   g_string_append (cmdstr, "/tests/libtest.sh; ");
@@ -155,7 +155,8 @@ ot_test_setup_sysroot (GCancellable *cancellable,
     }
 
   /* Make sure deployments are mutable */
-  g_setenv ("OSTREE_SYSROOT_DEBUG", buf->str, TRUE);
+  if (!g_setenv ("OSTREE_SYSROOT_DEBUG", buf->str, TRUE))
+    return glnx_null_throw (error, "Failed to set environment variable OSTREE_SYSROOT_DEBUG");
 
   g_autoptr(GFile) sysroot_path = g_file_new_for_path ("sysroot");
   return ostree_sysroot_new (sysroot_path);
