@@ -15,9 +15,7 @@
 # Lesser General Public License for more details.
 #
 # You should have received a copy of the GNU Lesser General Public
-# License along with this library; if not, write to the
-# Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-# Boston, MA 02111-1307, USA.
+# License along with this library. If not, see <https://www.gnu.org/licenses/>.
 
 set -euo pipefail
 
@@ -54,11 +52,12 @@ function verify_initial_contents() {
     assert_file_has_content baz/cow '^moo$'
 }
 
+n_base_tests=35
+gpg_tests=3
 if has_gpgme; then
-    echo "1..36"
+    echo "1..$(($n_base_tests+$gpg_tests))"
 else
-    # 3 tests needs GPG support
-    echo "1..33"
+    echo "1..$((n_base_tests))"
 fi
 
 # Try both syntaxes
@@ -142,6 +141,14 @@ ${CMD_PREFIX} ostree --repo=mirrorrepo pull origin main
 ${CMD_PREFIX} ostree --repo=mirrorrepo fsck
 echo "ok pull (refuses deltas)"
 
+${CMD_PREFIX} ostree --repo=mirrorrepo remote add broken badscheme://something
+if ${CMD_PREFIX} ostree --repo=mirrorrepo pull broken main 2>err.txt; then
+  assert_not_reached "pulled from invalid"
+fi
+assert_file_has_content_literal err.txt "Invalid URI scheme in badscheme://something"
+${CMD_PREFIX} ostree --repo=mirrorrepo remote delete broken
+echo "ok clean error on invalid scheme"
+
 cd ${test_tmpdir}
 rm mirrorrepo/refs/remotes/* -rf
 ${CMD_PREFIX} ostree --repo=mirrorrepo prune --refs-only
@@ -196,7 +203,7 @@ if ! skip_one_without_user_xattrs; then
         # Preserve user.ostreemeta xattr
         cp -a ${path}{,.new}
         (dd if=${path} conv=swab) > ${path}.new
-        mv ${path}{.new,}
+        mv -f ${path}{.new,}
         if ${CMD_PREFIX} ostree --repo=cacherepo fsck 2>err.txt; then
             fatal "corrupt repo fsck?"
         fi
@@ -590,6 +597,33 @@ assert_file_has_content err.txt "ONE BILLION DOLLARS"
 
 echo "ok unconfigured"
 
+cd ${test_tmpdir}
+${CMD_PREFIX} ostree --repo=repo remote add --custom-backend=ostree-rs-ext fromcontainer
+if ${CMD_PREFIX} ostree --repo=repo pull fromcontainer 2>err.txt; then
+    assert_not_reached "pull unexpectedly succeeded?"
+fi
+assert_file_has_content err.txt "remote 'fromcontainer' uses custom backend 'ostree-rs-ext'"
+
+for x in show-url refs; do
+if ${CMD_PREFIX} ostree --repo=repo remote "$x" fromcontainer 2>err.txt; then
+assert_file_has_content err.txt "remote 'fromcontainer' uses custom backend 'ostree-rs-ext'"
+    assert_not_reached "no url expected"
+fi
+assert_file_has_content err.txt "No \"url\" option in remote"
+done
+${CMD_PREFIX} ostree --repo=repo remote delete fromcontainer
+
+${CMD_PREFIX} ostree --repo=repo remote add --custom-backend=ostree-rs-ext fromcontainer2 docker://quay.io/examplecorp/foo
+if ${CMD_PREFIX} ostree --repo=repo pull fromcontainer2 main 2>err.txt; then
+    assert_not_reached "pull unexpectedly succeeded?"
+fi
+assert_file_has_content err.txt "remote 'fromcontainer2' uses custom backend 'ostree-rs-ext'"
+${CMD_PREFIX} ostree --repo=repo remote show-url fromcontainer2 >out.txt
+assert_file_has_content out.txt docker://quay.io/examplecorp/foo
+${CMD_PREFIX} ostree --repo=repo remote delete fromcontainer2
+
+echo "ok custom backend"
+
 cd ${test_tmpdir}
 repo_init
 ${CMD_PREFIX} ostree --repo=repo remote add origin-bad $(cat httpd-address)/ostree/noent
@@ -631,12 +665,12 @@ if has_gpgme; then
     objpath=objects/${csum::2}/${csum:2}.commitmeta
     remotesig=ostree-srv/gnomerepo/$objpath
     localsig=repo/$objpath
-    mv $remotesig $remotesig.bak
+    mv -f $remotesig $remotesig.bak
     if ${CMD_PREFIX} ostree --repo=repo --depth=0 pull origin main; then
         assert_not_reached "pull with gpg-verify unexpectedly succeeded?"
     fi
     # ok now check that we can pull correctly
-    mv $remotesig.bak $remotesig
+    mv -f $remotesig.bak $remotesig
     ${CMD_PREFIX} ostree --repo=repo pull origin main
     echo "ok pull signed commit"
     rm $localsig
