@@ -14,9 +14,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this library. If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
@@ -80,7 +78,8 @@ test_fixture_setup (TestFixture *fixture,
    * certificates for certain test cases. */
 
   homedir = g_test_build_filename (G_TEST_DIST, "tests/gpg-verify-data", NULL);
-  g_setenv ("GNUPGHOME", homedir, TRUE);
+  gboolean is_ok = g_setenv ("GNUPGHOME", homedir, TRUE);
+  g_assert (is_ok == TRUE);
 
   result = g_initable_new (OSTREE_TYPE_GPG_VERIFY_RESULT,
                            NULL, &local_error, NULL);
